@@ -239,7 +239,7 @@
 #define ISC_PLATFORM_USETHREADS 1
 
 /*
- * Defined if unistd.h does not cause fd_set to be delared.
+ * Defined if unistd.h does not cause fd_set to be declared.
  */
 #define ISC_PLATFORM_NEEDSYSSELECTH 1
 
@@ -296,31 +296,31 @@
  * If the "xadd" operation is available on this architecture,
  * ISC_PLATFORM_HAVEXADD will be defined.
  */
-#undef ISC_PLATFORM_HAVEXADD
+#define ISC_PLATFORM_HAVEXADD 1
 
 /*
  * If the "xaddq" operation (64bit xadd) is available on this architecture,
  * ISC_PLATFORM_HAVEXADDQ will be defined.
  */
-#undef ISC_PLATFORM_HAVEXADDQ
+#define ISC_PLATFORM_HAVEXADDQ 1
 
 /*
  * If the 32-bit "atomic swap" operation is available on this
  * architecture, ISC_PLATFORM_HAVEATOMICSTORE" will be defined.
  */
-#undef ISC_PLATFORM_HAVEATOMICSTORE
+#define ISC_PLATFORM_HAVEATOMICSTORE 1
 
 /*
  * If the 64-bit "atomic swap" operation is available on this
  * architecture, ISC_PLATFORM_HAVEATOMICSTORE" will be defined.
  */
-#undef ISC_PLATFORM_HAVEATOMICSTOREQ
+#define ISC_PLATFORM_HAVEATOMICSTOREQ 1
 
 /*
  * If the "compare-and-exchange" operation is available on this architecture,
  * ISC_PLATFORM_HAVECMPXCHG will be defined.
  */
-#undef ISC_PLATFORM_HAVECMPXCHG
+#define ISC_PLATFORM_HAVECMPXCHG 1
 
 /*
  * If <stdatomic.h> is available on this architecture,
@@ -331,7 +331,7 @@
 /*
  * Define if gcc ASM extension is available
  */
-#undef ISC_PLATFORM_USEGCCASM
+#define ISC_PLATFORM_USEGCCASM 1
 
 /*
  * Define if Tru64 style ASM syntax must be used.
@@ -346,7 +346,7 @@
 /*
  * Define with the busy wait nop asm or function call.
  */
-
+#define ISC_PLATFORM_BUSYWAITNOP asm("rep; nop")
 
 /*
  * Define if the platform has <strings.h>.
